@@ -1,10 +1,25 @@
 """Time utils."""
 import time
 import datetime
-from pytz import timezone
 
 DEFAULT_TIME_FORMAT = '%Y-%m-%d %H:%M:%S'
-DEFAULT_TZINFO = timezone('Asia/Colombo')
+
+
+class SECONDS_IN:
+    """Units of time."""
+    MINUTE = 60
+    HOUR = 3600
+    DAY = 86400
+    WEEK = 7 * 86400
+    FORTNIGHT = 14 * 86400
+    MONTH = 365.25 * 4 * 86400 / 12
+    QTR = 365.25 * 86400 / 4
+    YEAR = 365.25 * 86400
+
+
+def get_timezone():
+    """Get timezone."""
+    return str(datetime.datetime.now().astimezone().tzinfo)
 
 
 def get_unixtime():
@@ -15,22 +30,18 @@ def get_unixtime():
 def parse_time(
     time_str,
     time_format=DEFAULT_TIME_FORMAT,
-    tzinfo=DEFAULT_TZINFO,
 ):
     """Parse time string, and return unixtime."""
     _datetime = datetime.datetime.strptime(time_str, time_format)
-    _datetime = _datetime.replace(tzinfo=tzinfo)
     return (int)(time.mktime(_datetime.timetuple()))
 
 
 def format_time(
     unixtime,
     time_format=DEFAULT_TIME_FORMAT,
-    tzinfo=DEFAULT_TZINFO,
 ):
     """Format unixtime as time string."""
     _datetime = datetime.datetime.fromtimestamp(unixtime)
-    _datetime = _datetime.replace(tzinfo=tzinfo)
     return _datetime.strftime(time_format)
 
 
